@@ -19,6 +19,14 @@ class First(ast.AST):
     _fields = ['source']
 
 
+class Last(ast.AST):
+    _fields = ['source']
+
+
+class ElementAt(ast.AST):
+    _fields = ['source', 'index']
+
+
 class Aggregate(ast.AST):
     _fields = ['source', 'seed', 'func']
 
@@ -55,6 +63,8 @@ linq_operator_names = ('Where',
                        'Select',
                        'SelectMany',
                        'First',
+                       'Last',
+                       'ElementAt',
                        'Aggregate',
                        'Count',
                        'Max',
@@ -115,6 +125,14 @@ class InsertLINQNodesTransformer(ast.NodeTransformer):
             if len(args) != 0:
                 raise SyntaxError('First() call must have zero arguments')
             return First(source=self.visit(source))
+        elif function_name == 'Last':
+            if len(args) != 0:
+                raise SyntaxError('Last() call must have zero arguments')
+            return Last(source=self.visit(source))
+        elif function_name == 'ElementAt':
+            if len(args) != 1:
+                raise SyntaxError('ElementAt() call must have exactly one argument')
+            return ElementAt(source=self.visit(source), index=self.visit(args[0]))
         elif function_name == 'Aggregate':
             if len(args) != 2:
                 raise SyntaxError('Aggregate() call must have exactly two arguments; found'
